==> aws-cdk.aws-memorydb-1.151.0.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_aws_memorydb_CfnACLProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.tags))
        require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_memorydb_CfnUserProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.tags))
        require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_memorydb_CfnParameterGroupProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.tags))
        require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_memorydb_CfnSubnetGroupProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.tags))
        require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_memorydb_CfnClusterProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.tags))
        require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_memorydb_CfnACL(p) {
}
function _aws_cdk_aws_memorydb_CfnSubnetGroup(p) {
}
function _aws_cdk_aws_memorydb_CfnUser(p) {
}
function _aws_cdk_aws_memorydb_CfnParameterGroup(p) {
}
function _aws_cdk_aws_memorydb_CfnCluster(p) {
}
function _aws_cdk_aws_memorydb_CfnCluster_EndpointProperty(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_aws_memorydb_CfnACLProps, _aws_cdk_aws_memorydb_CfnUserProps, _aws_cdk_aws_memorydb_CfnParameterGroupProps, _aws_cdk_aws_memorydb_CfnSubnetGroupProps, _aws_cdk_aws_memorydb_CfnClusterProps, _aws_cdk_aws_memorydb_CfnACL, _aws_cdk_aws_memorydb_CfnSubnetGroup, _aws_cdk_aws_memorydb_CfnUser, _aws_cdk_aws_memorydb_CfnParameterGroup, _aws_cdk_aws_memorydb_CfnCluster, _aws_cdk_aws_memorydb_CfnCluster_EndpointProperty };
module.exports.DeprecationError = DeprecationError;

==> aws-cdk.aws-memorydb-1.152.0.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_aws_memorydb_CfnACLProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.tags))
        require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_memorydb_CfnUserProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.tags))
        require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_memorydb_CfnParameterGroupProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.tags))
        require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_memorydb_CfnSubnetGroupProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.tags))
        require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_memorydb_CfnClusterProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.tags))
        require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_memorydb_CfnACL(p) {
}
function _aws_cdk_aws_memorydb_CfnSubnetGroup(p) {
}
function _aws_cdk_aws_memorydb_CfnParameterGroup(p) {
}
function _aws_cdk_aws_memorydb_CfnUser(p) {
}
function _aws_cdk_aws_memorydb_CfnCluster(p) {
}
function _aws_cdk_aws_memorydb_CfnCluster_EndpointProperty(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_aws_memorydb_CfnACLProps, _aws_cdk_aws_memorydb_CfnUserProps, _aws_cdk_aws_memorydb_CfnParameterGroupProps, _aws_cdk_aws_memorydb_CfnSubnetGroupProps, _aws_cdk_aws_memorydb_CfnClusterProps, _aws_cdk_aws_memorydb_CfnACL, _aws_cdk_aws_memorydb_CfnSubnetGroup, _aws_cdk_aws_memorydb_CfnParameterGroup, _aws_cdk_aws_memorydb_CfnUser, _aws_cdk_aws_memorydb_CfnCluster, _aws_cdk_aws_memorydb_CfnCluster_EndpointProperty };
module.exports.DeprecationError = DeprecationError;
